aboutsummaryrefslogtreecommitdiffstats
path: root/include/asm-m32r/unistd.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/asm-m32r/unistd.h')
-rw-r--r--include/asm-m32r/unistd.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/include/asm-m32r/unistd.h b/include/asm-m32r/unistd.h
index 89f376e6229f..5c6a9ac6cf1a 100644
--- a/include/asm-m32r/unistd.h
+++ b/include/asm-m32r/unistd.h
@@ -296,8 +296,9 @@
#ifdef __KERNEL__
#define NR_syscalls 285
/* user-visible error numbers are in the range -1 - -124: see
* <asm-m32r/errno.h>
*/
@@ -305,7 +306,7 @@
#define __syscall_return(type, res) \
do { \
- if ((unsigned long)(res) >= (unsigned long)(-(124 + 1))) { \
+ if ((unsigned long)(res) >= (unsigned long)(-MAX_ERRNO)) { \
/* Avoid using "res" which is declared to be in register r0; \
errno might expand to a function call and clobber it. */ \
int __err = -(res); \
@@ -296,8 +296,9 @@
#ifdef __KERNEL__
#define NR_syscalls 285
+#include <linux/err.h>
-/* user-visible error numbers are in the range -1 - -124: see
+/* user-visible error numbers are in the range -1 - -MAX_ERRNO: see
* <asm-m32r/errno.h>
*/